@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2014-2018 by Dominique Dumont.
+# This software is Copyright (c) 2014-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.030';
+$App::Cme::Common::VERSION = '1.033';
 use strict;
 use warnings;
 use 5.10.1;
@@ -25,6 +25,8 @@ use Encode qw(decode_utf8);
 
 my @store;
 
+$::_use_log4perl_to_warn = 1;
+
 sub cme_global_options {
   my ( $class, $app ) = @_;
 
@@ -33,7 +35,7 @@ sub cme_global_options {
       [ "try-app-as-model!"  => "try to load a model using directly the application name "
                               . "specified as 3rd parameter on the command line"],
       [ "save!"              => "Force a save even if no change was done" ],
-      [ "force-load!"        => "Load file even if error are found in data. Bad data are discarded (imply save)"],
+      [ "force-load!"        => "Load file even if error are found in data. Errors must be fixed before saving."],
       [ "create!"            => "start from scratch."],
       [ "root-dir=s"         => "Change root directory. Mostly used for test"],
       [ "file=s"             => "Specify a target file"],
@@ -57,6 +59,7 @@ sub check_unknown_args {
     my @unknown_options = grep { /^-/ } @$args ;
     # $self->usage_error("Unknown option: @unknown_options") if @unknown_options;
     warn("Unknown option: @unknown_options. Unknown option will soon be a fatal error.") if @unknown_options;
+    return;
 }
 
 # modifies $args in place
@@ -130,8 +133,9 @@ sub process_args {
     $opt->{_application} = $application ;
     $opt->{_config_file} = $config_file;
     $opt->{_root_model}  = $root_model;
-}
 
+    return;
+}
 
 sub model {
     my ($self, $opt, $args) = @_;
@@ -170,9 +174,9 @@ sub instance {
 }
 
 sub init_cme {
-    my $self = shift;
+    my ($self, @args) = @_;
     # model and inst are deleted if not kept in a scope
-    return ( $self->model(@_) , $self->instance(@_), $self->instance->config_root );
+    return ( $self->model(@args) , $self->instance(@args), $self->instance->config_root );
 }
 
 sub save {
@@ -184,35 +188,37 @@ sub save {
     # at semantic level, i.e. removed unnecessary stuff)
     $inst->write_back( force => $opt->{force_load} || $opt->{save} );
 
+    return;
 }
 
 sub run_tk_ui {
-    my ($self, $root, $opt) = @_;
+    my ($self, $instance, $opt) = @_;
 
     require Config::Model::TkUI;
     require Tk;
     require Tk::ErrorDialog;
     Tk->import;
 
-    no warnings 'once';
+    no warnings 'once'; ## no critic TestingAndDebugging::ProhibitNoWarnings
     my $mw = MainWindow->new;
     $mw->withdraw;
 
     # Thanks to Jerome Quelin for the tip
     $mw->optionAdd( '*BorderWidth' => 1 );
 
-    my $cmu = $mw->ConfigModelUI(
-        -root       => $root,
-    );
+    # -root parameter is deprecated
+    my $cmu = $mw->ConfigModelUI( -instance => $instance );
 
-    $root->instance->on_message_cb(sub{$cmu->show_message(@_);});
+    $instance->on_message_cb(sub{$cmu->show_message(@_);});
 
     if ($opt->{open_item}) {
-        my $obj = $root->grab($opt->{open_item});
+        my $obj = $instance->grab($opt->{open_item});
         $cmu->force_element_display($obj);
     }
 
     &MainLoop;    # Tk's
+
+    return;
 }
 
 sub run_shell_ui ($$$) {
@@ -226,6 +232,8 @@ sub run_shell_ui ($$$) {
 
     # engage in user interaction
     $shell_ui->run_loop;
+
+    return;
 }
 
 sub get_documentation {
@@ -259,7 +267,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.030
+version 1.033
 
 =head1 SYNOPSIS
 
@@ -275,7 +283,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014-2018 by Dominique Dumont.
+This software is Copyright (c) 2014-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
